import throttle from 'lodash.throttle';

/**
 * Throttle time for events' listeners
 * @type {Number}
 */
var THROTTLE_TIME = 500;

/**
 * Options for resize event's listeners
 * @type {Object}
 */
var EVENT_OPTIONS = {
  capture: true,
  passive: true
};

/**
 * Callbacks to execute on each resize event.
 * @type {Array<Function>}
 */
var listeners = [];

/**
 * Service to get width and height of the viewport
 */
var ViewportResize = /*#__PURE__*/function () {
  function ViewportResize() {}
  /**
   * Register event to update viewport width and height
   * @param {Function} listener
   */
  ViewportResize.addListener = function addListener(listener) {
    listeners.push(listener);
    this.update();
    if (listeners.length) {
      window.addEventListener('resize', this.update, EVENT_OPTIONS);
    }
  }

  /**
   * Unregister event to update viewport width and height
   * @param {Function} listener
   */;
  ViewportResize.removeListener = function removeListener(listener) {
    listeners = listeners.filter(function (cb) {
      return cb !== listener;
    });
    if (!listeners.length) {
      window.removeEventListener('resize', this.update, EVENT_OPTIONS);
    }
  }

  /**
   * Take viewport limits and update width and height
   */;
  ViewportResize.update = function update() {
    var _this = this;
    this.height = document.body.clientHeight;
    this.width = document.body.clientWidth;
    listeners.forEach(function (cb) {
      return cb(_this.width, _this.height);
    });
  };
  return ViewportResize;
}();
ViewportResize.update = throttle(ViewportResize.update, THROTTLE_TIME);
export default ViewportResize;